@@ -67,15 +67,15 @@ def display_alert(args,printer):
     # msg.show ()
     cmd = construct_notification_command(alert_title, alert_message, urgency)
     #    pdb.set_trace()
-    printer ("The Command:", str(cmd))
-    # call(cmd)    
+    # printer ("The Command:", str(cmd))
+    call(cmd)    
     
 def play_sound(args,printer):
     a = 1
     filename = u"~/bin/sounds/" + args[u'sound_file'] + u".ogg"    
     cmd = [u"play", u"-q", filename]
-    printer ("The Command:", str(cmd))
-    #call(cmd)
+    # printer ("The Command:", str(cmd))
+    call(cmd)
 
 
 #########################
@@ -110,7 +110,6 @@ def test_begins_with_dash ():
 ##########################
 ## HELPERS
 
-
 def trim_leading_dashes(strng):
     # pdb.set_trace()
     while begins_with_dash(strng):
